@@ -1,5 +1,5 @@
 import os
-from typing import Optional
+from typing import Optional, DefaultDict
 
 from algoralabs.decorators.configuration import configuration
 from algoralabs.gData import config_file
@@ -45,5 +45,9 @@ app_config = AppConfig()
 
 @configuration(yaml_file=config_file, prefix=app_config.environment)
 class EnvironmentConfig:
-    base_url: str
+    urls: dict
     auth_config: Auth = Auth()
+
+    def get_url(self, key="algora"):
+        return self.urls.get(key, self.urls["algora"])
+
