@@ -1,15 +1,32 @@
-from algoralabs.data.iex.utils import __base_request
+from typing import List, Union, Dict
+
+from pandas import DataFrame
+
+from algoralabs.data.iex.utils import __base_request, transform_one_or_many
 from algoralabs.data.transformations.response_transformers import no_transform
 from algoralabs.decorators.data import data_request
 
 
 @data_request
-def historical_prices(symbol: str, **kwargs):
+def symbols() -> DataFrame:
+    """
+    Symbols that IEX Cloud supports for intraday price updates.
+
+    Reference: https://iexcloud.io/docs/api/#symbols
+
+    :return: Dataframe of data
+    """
+
+    return __base_request(f"ref-data/symbols")
+
+
+@data_request(transformer=lambda d: transform_one_or_many(d, 'chart'))
+def historical_prices(*symbol: str, **kwargs) -> Union[DataFrame, Dict[str, DataFrame]]:
     """
     Historical Prices via Time Series Endpoint
     Reference: https://iexcloud.io/docs/api/#time-series-endpoint
 
-    :param symbol: (str) Stock symbol, such as AAPL
+    :param symbol: (*str) Stock symbol(s), such as "AAPL" or "AAPL", "FB"
     :param range: (str) Optional. Returns data for a given range. Supported ranges described below.
     :param calendar: (bool) Optional. Boolean. Used in conjunction with `range` to return data in the future.
     :param limit: (int) Optional. Limits the number of results returned. Defaults to 1 when no date or range
@@ -61,11 +78,15 @@ def historical_prices(symbol: str, **kwargs):
     }
     params.update(kwargs)
 
-    return __base_request(f"time-series/HISTORICAL_PRICES/{symbol}", **params)
+    if len(symbol) > 1:
+        params.update({'symbols': ','.join(symbol), 'types': 'chart'})
+        return __base_request(f"stock/market/batch", **params)
+
+    return __base_request(f"time-series/HISTORICAL_PRICES/{symbol[0]}", **params)
 
 
 @data_request
-def news(symbol: str, **kwargs):
+def news(symbol: str, **kwargs) -> DataFrame:
     """
     News for given symbol
     Reference: https://iexcloud.io/docs/api/#news
@@ -120,7 +141,7 @@ def news(symbol: str, **kwargs):
 
 
 @data_request(transformer=no_transform)
-def peer_group(symbol: str):
+def peer_group(symbol: str) -> List[str]:
     """
     Stock peers
     Reference: https://iexcloud.io/docs/api/#peers
