@@ -35,7 +35,9 @@ def data_request(
             """
             response: Response = f(*args, **kwargs)
             if response.status_code != 200 | response.status_code != 201:
-                error = ApiError(f"Request to {response.url} failed with status code {response.status_code}")
+                error = ApiError(
+                    f"Request to {response.url} failed with status code {response.status_code}: {response.text}"
+                )
                 logger.error(error)
                 raise error
 
